"use strict";
var __makeTemplateObject = (this && this.__makeTemplateObject) || function (cooked, raw) {
    if (Object.defineProperty) { Object.defineProperty(cooked, "raw", { value: raw }); } else { cooked.raw = raw; }
    return cooked;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@babel/core");
var plugin_1 = __importDefault(require("./plugin"));
var transformCode = function (opts) { return function (code) {
    return core_1.transform(code[0], {
        plugins: ["@babel/transform-react-jsx", [plugin_1.default, opts]]
    }).code;
}; };
describe("plugin", function () {
    it("replaces $TestId in properties", function () {
        expect(transformCode()(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n          const x = {\n              prop: $TestId.Hello\n          }\n        "], ["\n          const x = {\n              prop: $TestId.Hello\n          }\n        "])))).toMatchSnapshot();
    });
    it("replaces $TestId in properties with custom magic object", function () {
        expect(transformCode({ magicObject: "$Alex" })(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n          const x = {\n              prop: $Alex.Hello\n          }\n        "], ["\n          const x = {\n              prop: $Alex.Hello\n          }\n        "])))).toMatchSnapshot();
    });
    it("replaces $TestId in jsx attributes", function () {
        expect(transformCode()(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n          const x = (\n              <div data-testid={$TestId.One} id={$TestId.Two} />\n          )\n        "], ["\n          const x = (\n              <div data-testid={$TestId.One} id={$TestId.Two} />\n          )\n        "])))).toMatchSnapshot();
    });
    it("throws if naked magicObject is used", function () {
        expect(function () { return transformCode()(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n            const x = {\n                prop: $TestId\n            }\n        "], ["\n            const x = {\n                prop: $TestId\n            }\n        "]))); }).toThrowErrorMatchingSnapshot();
    });
    it("throws if naked magicObject is used as auto property", function () {
        expect(function () { return transformCode()(templateObject_5 || (templateObject_5 = __makeTemplateObject(["\n            const x = {\n                $TestId\n            }\n        "], ["\n            const x = {\n                $TestId\n            }\n        "]))); }).toThrowErrorMatchingSnapshot();
    });
    it("throws if naked magicObject is in jsx attribute", function () {
        expect(function () { return transformCode()(templateObject_6 || (templateObject_6 = __makeTemplateObject(["\n            const x = (\n                <div data-testid={$TestId} />\n            )\n        "], ["\n            const x = (\n                <div data-testid={$TestId} />\n            )\n        "]))); }).toThrowErrorMatchingSnapshot();
    });
    it("writes found testIds", function () {
        var fs = {
            mkdirpSync: jest.fn(),
            writeFileSync: jest.fn()
        };
        transformCode({ fs: fs, extractTo: "test" })(templateObject_7 || (templateObject_7 = __makeTemplateObject(["\n            const x = {\n                prop: $TestId.Hello,\n                prop2: $TestId.GoodBye\n            }\n        "], ["\n            const x = {\n                prop: $TestId.Hello,\n                prop2: $TestId.GoodBye\n            }\n        "])));
        expect(fs.writeFileSync.mock.calls).toMatchSnapshot();
    });
});
var templateObject_1, templateObject_2, templateObject_3, templateObject_4, templateObject_5, templateObject_6, templateObject_7;
